Package: htmlTable
Version: 2.4.3
Title: Advanced Tables for Markdown/HTML
Authors@R: c(
  person("Max", "Gordon", email = "max@gforge.se",
         role = c("aut", "cre")),
  person("Stephen", "Gragg", role=c("aut")),
  person("Peter", "Konings", role=c("aut")))
Maintainer: Max Gordon <max@gforge.se>
Description: Tables with state-of-the-art layout elements such as row spanners,
    column spanners, table spanners, zebra striping, and more. While allowing
    advanced layout, the underlying css-structure is simple in order to maximize
    compatibility with common word processors. The package also contains a few
    text formatting functions that help outputting text compatible with HTML/LaTeX.
License: GPL (>= 3)
URL: https://gforge.se/packages/
BugReports: https://github.com/gforge/htmlTable/issues
Biarch: yes
Depends: R (>= 4.1)
Imports: stringr, knitr (>= 1.6), magrittr (>= 1.5), methods,
        checkmate, htmlwidgets, htmltools, rstudioapi (>= 0.6)
Suggests: testthat, XML, xml2, Hmisc, rmarkdown, chron, lubridate,
        tibble, purrr, tidyselect, glue, rlang, tidyr (>= 0.7.2), dplyr
        (>= 0.7.4)
Encoding: UTF-8
NeedsCompilation: no
VignetteBuilder: knitr
RoxygenNote: 7.2.2
Packaged: 2024-07-20 06:52:16 UTC; max
Author: Max Gordon [aut, cre],
  Stephen Gragg [aut],
  Peter Konings [aut]
Repository: CRAN
Date/Publication: 2024-07-21 00:30:08 UTC
Built: R 4.5.2; ; 2026-04-06 06:48:18 UTC; unix
