Package: htmlTable
Version: 1.12
Date: 2018-05-25
Title: Advanced Tables for Markdown/HTML
Authors@R: c(
  person("Max", "Gordon", email = "max@gforge.se",
         role = c("aut", "cre")),
  person("Stephen", "Gragg", role=c("aut")),
  person("Peter", "Konings", role=c("aut")))
Maintainer: Max Gordon <max@gforge.se>
Description: Tables with state-of-the-art layout elements such as row spanners,
    column spanners, table spanners, zebra striping, and more. While allowing
    advanced layout, the underlying css-structure is simple in order to maximize
    compatibility with word processors such as 'MS Word' or 'LibreOffice'. The package
    also contains a few text formatting functions that help outputting text
    compatible with HTML/LaTeX.
License: GPL (>= 3)
URL: http://gforge.se/packages/
BugReports: https://github.com/gforge/htmlTable/issues
Biarch: yes
Imports: stringr, knitr (>= 1.6), magrittr (>= 1.5), methods,
        checkmate, htmlwidgets, htmltools, rstudioapi (>= 0.6)
Suggests: testthat, XML, xtable, ztable, Hmisc, reshape, rmarkdown,
        pander, chron, lubridate, tibble, tidyr (>= 0.7.2), dplyr (>=
        0.7.4)
Encoding: UTF-8
NeedsCompilation: no
VignetteBuilder: knitr
RoxygenNote: 6.0.1
Packaged: 2018-05-26 18:15:53 UTC; max
Author: Max Gordon [aut, cre],
  Stephen Gragg [aut],
  Peter Konings [aut]
Repository: CRAN
Date/Publication: 2018-05-26 22:01:20 UTC
Built: R 3.4.1; ; 2018-09-29 09:20:14 UTC; windows
